Athletic: Intercollegiate Athletic Program Data Set
Description
The Athletic data set has 168 observations and 7 variables.
The data come from a survey of stakeholders different (students, alumni, faculty, and
athletic department employees) of a large US state university. The variables in
the data set are conjoint analysis based relative importance weights for seven
potential indicators of intercollegiate athletic program success.source
Wolfe, Richard A. and Daniel S. Putler (2002), "How Tight are the Ties that
Bind Stakeholder Groups?, Organizaton Science, 13(January-February),
64-82.